@@ -22,7 +22,7 @@ for ( keys %EXPORT_TAGS ){
 	push(@{ $EXPORT_TAGS{"all"} },  @{$EXPORT_TAGS{$_}} );
 }
 
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -60,12 +60,14 @@ Gsl - Perl Interface to The GNU Scientific Library
 =head1 SYNOPSIS
 
   use Math::Gsl;
-  use Math::Gsl::Sf;	# use Special Function library
+  use Math::Gsl::Sf;	     # use Special Function library
+  use Math::Gsl::Polynomial; # use poly_complex_solve
 
 
 =head1 DESCRIPTION
 
-  Currently this module only implements the GSL Special function library.
+  Currently this module implements the GSL Special function library and the
+  single GSL function poly_complex_solve.
   Please see the manual page for Math::Gsl::Sf for relevant documenation.
 
 
@@ -85,6 +87,6 @@ Jonathan Leto, jonathan@leto.net
 
 GNU Scientific Library http://sources.redhat.com/gsl
 
-To get Gsl: http://www.leto.net/code/gsl/
+To get Math::Gsl: http://www.leto.net/code/gsl/
 
 =cut
