@@ -107,7 +107,7 @@ for ( @{$EXPORT_TAGS{"all"}} ){
 	eval $str;
 	print $@ if $@;
 }
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 sub AUTOLOAD {
 	
@@ -223,6 +223,6 @@ Jonathan Leto, jonathan@leto.net
 
 GNU Scientific Library http://sources.redhat.com/gsl
 
-To get Gsl: http://www.leto.net/code/gsl/
+To get Math::Gsl: http://www.leto.net/code/gsl/
 
 =cut
